diff --git a/build/cflags.m4 b/build/cflags.m4
index 01427d8..f8cb42e 100644
--- a/build/cflags.m4
+++ b/build/cflags.m4
@@ -45,3 +45,34 @@ AC_DEFUN([GP_CHECK_CFLAGS],
     GP_STATUS_BUILD_FEATURE_ADD([Extra C compiler warnings],
                                 [$enable_extra_c_warnings])
 ])
+
+dnl GP_CHECK_VALA_CFLAGS
+dnl Checks for default Geany-Plugins CFLAGS used for Vala targets,
+dnl and defines GP_VALA_CFLAGS
+AC_DEFUN([GP_CHECK_VALA_CFLAGS],
+[
+    AC_ARG_ENABLE([reduced-vala-c-warnings],
+                  AS_HELP_STRING([--disable-reduced-vala-c-warnings],
+                      [Disable reduced C Compiler warnings for Vala-generated code]),
+                  [enable_reduced_vala_c_warnings=$enableval],
+                  [enable_reduced_vala_c_warnings=yes])
+
+    GP_VALA_CFLAGS=
+    AS_IF([test "x$enable_reduced_vala_c_warnings" != xno],
+    [
+        enable_reduced_vala_c_warnings=yes
+        for flag in -Wno-conversion \
+                    -Wno-pedantic \
+                    -Wno-redundant-decls \
+                    -Wno-sign-compare \
+                    -Wno-unused \
+                    -Wno-unused-but-set-parameter \
+                    -Wno-unused-but-set-variable \
+                    -Wno-unused-parameter \
+                    -Wno-unused-variable
+        do
+            _GP_CHECK_CFLAG_([$flag], [GP_VALA_CFLAGS="${GP_VALA_CFLAGS} $flag"])
+        done
+    ])
+    AC_SUBST([GP_VALA_CFLAGS])
+])
diff --git a/configure.ac b/configure.ac
index 703a853..a913e96 100644
--- a/configure.ac
+++ b/configure.ac
@@ -23,6 +23,7 @@ GP_CHECK_UNITTESTS(0.9.4)
 GP_CHECK_GTK_VERSION
 GP_CHECK_CPPCHECK
 GP_CHECK_CFLAGS
+GP_CHECK_VALA_CFLAGS
 
 dnl plugin checks
 GP_CHECK_ADDONS
diff --git a/multiterm/src/Makefile.am b/multiterm/src/Makefile.am
index 70447ff..50c9aa3 100644
--- a/multiterm/src/Makefile.am
+++ b/multiterm/src/Makefile.am
@@ -3,6 +3,9 @@ include $(top_srcdir)/build/vars.docs.mk
 
 plugin = multiterm
 
+CFLAGS ?=
+CFLAGS += $(GP_VALA_CFLAGS)
+
 geanyplugins_LTLIBRARIES = multiterm.la
 
 multiterm_la_VALAFLAGS = \
